@@ -100,6 +100,8 @@ void notcurses_drop_planes(struct notcurses* nc);
 int notcurses_refresh(struct notcurses* n);
 int notcurses_resize(struct notcurses* n, int* y, int* x);
 struct ncplane* ncplane_new(struct notcurses* nc, int rows, int cols, int yoff, int xoff, void* opaque);
+struct ncplane* ncplane_bound(struct ncplane* n, int rows, int cols, int yoff, int xoff, void* opaque);
+struct ncplane* ncplane_reparent(struct ncplane* n, struct ncplane* newparent);
 typedef enum {
   NCALIGN_LEFT,
   NCALIGN_CENTER,
@@ -127,7 +129,7 @@ int ncplane_move_bottom(struct ncplane* n);
 int ncplane_move_below(struct ncplane* n, struct ncplane* below);
 int ncplane_move_above(struct ncplane* n, struct ncplane* above);
 struct ncplane* ncplane_below(struct ncplane* n);
-char* notcurses_at_yx(struct notcurses* nc, int yoff, int xoff, cell* c);
+char* notcurses_at_yx(struct notcurses* nc, int yoff, int xoff, uint32_t* attrword, uint64_t* channels);
 int ncplane_at_cursor(struct ncplane* n, cell* c);
 int ncplane_at_yx(struct ncplane* n, int y, int x, cell* c);
 void* ncplane_set_userptr(struct ncplane* n, void* opaque);
@@ -408,6 +410,28 @@ int ncplane_rotate_cw(struct ncplane* n);
 int ncplane_rotate_ccw(struct ncplane* n);
 void ncplane_translate(const struct ncplane* src, const struct ncplane* dst, int* y, int* x);
 bool ncplane_translate_abs(const struct ncplane* n, int* y, int* x);
+typedef enum {
+  NCPLOT_1x1,   // full block                █
+  NCPLOT_2x1,   // full/(upper|left) blocks  █▀
+  NCPLOT_1x1x4, // shaded full blocks        █▓▒░
+  NCPLOT_4x1,   // four vert/horz levels     █▆▄▂ / ▎▌▊█
+  NCPLOT_8x1,   // eight vert/horz levels         █▇▆▅▄▃▂▁ / ▏▎▍▌▋▊▉█
+} ncgridgeom_e;
+typedef struct ncplot_options {
+  uint64_t maxchannel;
+  uint64_t minchannel;
+  ncgridgeom_e gridtype;
+  uint64_t rangex;
+  int64_t miny, maxy;
+  bool labelaxisd;
+  bool exponentialy;
+  bool vertical_indep;
+} ncplot_options;
+struct ncplot* ncplot_create(struct ncplane* n, const ncplot_options* opts);
+struct ncplane* ncplot_plane(struct ncplot* n);
+int ncplot_add_sample(struct ncplot* n, uint64_t x, int64_t y);
+int ncplot_set_sample(struct ncplot* n, uint64_t x, int64_t y);
+void ncplot_destroy(struct ncplot* n);
 """)
 
 if __name__ == "__main__":
